@@ -1,4 +1,4 @@
-// Copyright 2008-2012 severally by the contributors
+// Copyright 2008-2014 severally by the contributors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,12 +14,15 @@
 
 package net.sf.practicalxml;
 
+import java.math.BigDecimal;
 import java.text.DateFormat;
 import java.text.DecimalFormat;
+import java.text.DecimalFormatSymbols;
 import java.text.SimpleDateFormat;
 import java.util.Calendar;
 import java.util.Date;
 import java.util.GregorianCalendar;
+import java.util.Locale;
 import java.util.TimeZone;
 
 import net.sf.kdgcommons.lang.StringUtil;
@@ -161,6 +164,21 @@ public class XmlUtil
         return getXsdDecimalFormatter().format(value);
     }
 
+    /**
+     *  Parses an XML Schema <code>decimal</code> value. Note that the return
+     *  type is <code>BigDecimal</code>: this provides us exact representation
+     *  where necessary, and meets the spec's minimum requirement of 18 digits
+     *  of precision. Use <code>.toLong()</code>, <code>toDouble()</code>, or
+     *  equivalent to create the type that you want.
+     *
+     *  @since 1.1.19
+     */
+    public static BigDecimal parseXsdDecimal(String value)
+    {
+        // note: this constructor parses in a locale-independent format
+        return new BigDecimal(value.trim());
+    }
+
 
     /**
      *  Converts a <code>boolean</code> value to the literal strings "true" or
@@ -366,7 +384,8 @@ public class XmlUtil
         DecimalFormat format = _xsdDecimalFormatter.get();
         if (format == null)
         {
-            format = new DecimalFormat("#0.0################;-#");
+            format = new DecimalFormat("#0.0################;-#",
+                                       new DecimalFormatSymbols(Locale.US));
             _xsdDecimalFormatter.set(format);
         }
         return format;
