@@ -1,4 +1,4 @@
-// Copyright 2008-2012 severally by the contributors
+// Copyright 2008-2014 severally by the contributors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -30,6 +30,7 @@ import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Locale;
 import java.util.Map;
 import java.util.Set;
 import java.util.SortedMap;
@@ -45,6 +46,8 @@ import org.w3c.dom.Element;
 import org.w3c.dom.Node;
 
 import net.sf.kdgcommons.bean.IntrospectionCache;
+import net.sf.kdgcommons.codec.Base64Codec;
+import net.sf.kdgcommons.codec.HexCodec;
 import net.sf.kdgcommons.lang.ObjectUtil;
 import net.sf.kdgcommons.lang.StringUtil;
 import net.sf.practicalxml.DomUtil;
@@ -217,6 +220,13 @@ public class Xml2BeanConverter
         if (childKlass == null)
             return null;
 
+        if (childKlass == byte.class)
+        {
+            byte[] obj = tryConvertAsEncodedByteArray(elem);
+            if (obj != null)
+                return obj;
+        }
+
         List<Element> children = DomUtil.getChildren(elem);
         Object result = Array.newInstance(childKlass, children.size());
         int idx = 0;
@@ -228,6 +238,18 @@ public class Xml2BeanConverter
     }
 
 
+    private byte[] tryConvertAsEncodedByteArray(Element elem)
+    {
+        String text = DomUtil.getText(elem);
+        if (_options.contains(Xml2BeanOptions.BYTE_ARRAYS_AS_BASE64))
+            return (new Base64Codec()).toBytes(text);
+        else if (_options.contains(Xml2BeanOptions.BYTE_ARRAYS_AS_HEX))
+            return (new HexCodec()).toBytes(text);
+        else
+            return null;
+    }
+
+
     private Object tryConvertAsSimpleCollection(Element elem, Class<?> klass)
     {
         Collection<Object> result = instantiateCollection(klass);
@@ -505,8 +527,9 @@ public class Xml2BeanConverter
             }
             else
             {
+                // as-of JDK 8, Date.toString() always writes its output using Locale.US
                 if (_defaultDateFormat == null)
-                    _defaultDateFormat = new SimpleDateFormat("EEE MMM dd HH:mm:ss zzz yyyy");
+                    _defaultDateFormat = new SimpleDateFormat("EEE MMM dd HH:mm:ss zzz yyyy", Locale.US);
                 return _defaultDateFormat.parse(str);
             }
         }
