@@ -1,4 +1,4 @@
-// Copyright 2008-2012 severally by the contributors
+// Copyright 2008-2014 severally by the contributors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -160,9 +160,8 @@ implements Cloneable
 
 
     /**
-     *  Binds an {@link net.sf.practicalxml.xpath.AbstractFunction} to this
-     *  expression. Subsequent calls to this method with the same name will
-     *  silently replace the binding.
+     *  Binds a self-describing function to this expression. Subsequent calls
+     *  with the same name/arity will silently replace the binding.
      *  <p>
      *  Per the JDK documentation, user-defined functions must occupy their
      *  own namespace. You must bind a namespace for this function, and use
@@ -174,7 +173,7 @@ implements Cloneable
      *
      *  @return The wrapper, so that calls may be chained.
      */
-    public XPathWrapper bindFunction(AbstractFunction<?> func)
+    public XPathWrapper bindFunction(FunctionResolver.SelfDescribingFunction func)
     {
         _functions.addFunction(func);
         return this;
@@ -182,10 +181,9 @@ implements Cloneable
 
 
     /**
-     *  Binds an {@link net.sf.practicalxml.xpath.AbstractFunction} to this
-     *  expression, along with the prefix used to access that function.
-     *  Subsequent calls to this method with the same name will silently
-     *  replace the binding.
+     *  Binds a self-describing function to this expression, along with the
+     *  prefix used to access that function. This also establishes a namespace
+     *  binding for that prefix.
      *  <p>
      *  Per the JDK documentation, user-defined functions must occupy their
      *  own namespace. This method will retrieve the namespace from the
@@ -196,7 +194,7 @@ implements Cloneable
      *
      *  @return The wrapper, so that calls may be chained.
      */
-    public XPathWrapper bindFunction(AbstractFunction<?> func, String prefix)
+    public XPathWrapper bindFunction(FunctionResolver.SelfDescribingFunction func, String prefix)
     {
         _functions.addFunction(func);
         return bindNamespace(prefix, func.getNamespaceUri());
