@@ -1,4 +1,4 @@
-// Copyright 2008-2012 severally by the contributors
+// Copyright 2008-2014 severally by the contributors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -14,18 +14,17 @@
 
 package net.sf.practicalxml.xpath.function;
 
-import org.w3c.dom.Node;
+import java.util.List;
 
-import net.sf.practicalxml.xpath.AbstractFunction;
+import net.sf.practicalxml.xpath.AbstractStringFunction;
 
 
 /**
- *  Converts the string value of its argument &mdash; which must be
- *  either a literal string or a node/nodeset &mdash; to uppercase,
- *  using <code>java.lang.String.toUppercase()</code>.
+ *  Converts the string value of its argument to lowercase, using a locale-aware
+ *  conversion.
  */
 public class Lowercase
-extends AbstractFunction<String>
+extends AbstractStringFunction
 {
     public Lowercase()
     {
@@ -33,26 +32,8 @@ extends AbstractFunction<String>
     }
 
     @Override
-    protected String processArg(int index, Node value, String helper)
-        throws Exception
-    {
-        return (value != null)
-             ? processArg(index, value.getTextContent(), helper)
-             : "";
-    }
-
-    @Override
-    protected String processArg(int index, String value, String helper)
-        throws Exception
+    public Object evaluate(String value, List<?> args)
     {
         return value.toLowerCase();
     }
-
-
-    @Override
-    protected String processNullArg(int index, String helper)
-    throws Exception
-    {
-        return "";
-    }
 }
