@@ -1,4 +1,4 @@
-// Copyright 2008-2012 severally by the contributors
+// Copyright 2008-2014 severally by the contributors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -1047,4 +1047,73 @@ extends AbstractBeanConverterTestCase
         DomAsserts.assertEquals("custom subclass",      strDate, root, "/root/myDate");
     }
 
+
+    public void testDefaultByteArrayFormat() throws Exception
+    {
+        byte[] src = new byte[] { 0x12, 0x34, 0x56, 0x78, (byte)0x9A, (byte)0xBC, (byte)0xDE, (byte)0xF0 };
+
+        Bean2XmlConverter driver = new Bean2XmlConverter();
+        Element root = driver.convert(src, "root");
+//        System.out.println(OutputUtil.indentedString(root.getOwnerDocument(), 4));
+
+        DomAsserts.assertCount("number of child elements", 8,    root, "/root/*");
+        DomAsserts.assertEquals("first data element",     "18",  root, "/root/data[1]");
+        DomAsserts.assertEquals("last data element",      "-16", root, "/root/data[8]");
+    }
+
+
+    public void testByteArrayAsBase64() throws Exception
+    {
+        byte[] src = new byte[] { 0x12, 0x34, 0x56, 0x78, (byte)0x9A, (byte)0xBC, (byte)0xDE, (byte)0xF0 };
+
+        Bean2XmlConverter driver = new Bean2XmlConverter(Bean2XmlOptions.BYTE_ARRAYS_AS_BASE64);
+        Element root = driver.convert(src, "root");
+//        System.out.println(OutputUtil.indentedString(root.getOwnerDocument(), 4));
+
+        DomAsserts.assertCount("number of child elements", 0,              root, "/root/*");
+        DomAsserts.assertEquals("encoded data",            "EjRWeJq83vA=",  root, "/root");
+    }
+
+
+    public void testByteArrayAsBase64WithType() throws Exception
+    {
+        byte[] src = new byte[] { 0x12, 0x34, 0x56, 0x78, (byte)0x9A, (byte)0xBC, (byte)0xDE, (byte)0xF0 };
+
+        Bean2XmlConverter driver = new Bean2XmlConverter(Bean2XmlOptions.BYTE_ARRAYS_AS_BASE64, Bean2XmlOptions.USE_TYPE_ATTR);
+        Element root = driver.convert(src, "root");
+//        System.out.println(OutputUtil.indentedString(root.getOwnerDocument(), 4));
+
+        DomAsserts.assertCount("number of child elements", 0,              root, "/root/*");
+        DomAsserts.assertEquals("encoded data",            "EjRWeJq83vA=",  root, "/root");
+
+        assertType("type attribute", root, "xsd:base64Binary");
+    }
+
+
+    public void testByteArrayAsHex() throws Exception
+    {
+        byte[] src = new byte[] { 0x12, 0x34, 0x56, 0x78, (byte)0x9A, (byte)0xBC, (byte)0xDE, (byte)0xF0 };
+
+        Bean2XmlConverter driver = new Bean2XmlConverter(Bean2XmlOptions.BYTE_ARRAYS_AS_HEX);
+        Element root = driver.convert(src, "root");
+//        System.out.println(OutputUtil.indentedString(root.getOwnerDocument(), 4));
+
+        DomAsserts.assertCount("number of child elements", 0,                   root, "/root/*");
+        DomAsserts.assertEquals("encoded data",            "123456789ABCDEF0",  root, "/root");
+    }
+
+
+    public void testByteArrayAsHexWithType() throws Exception
+    {
+        byte[] src = new byte[] { 0x12, 0x34, 0x56, 0x78, (byte)0x9A, (byte)0xBC, (byte)0xDE, (byte)0xF0 };
+
+        Bean2XmlConverter driver = new Bean2XmlConverter(Bean2XmlOptions.BYTE_ARRAYS_AS_HEX, Bean2XmlOptions.USE_TYPE_ATTR);
+        Element root = driver.convert(src, "root");
+//        System.out.println(OutputUtil.indentedString(root.getOwnerDocument(), 4));
+
+        DomAsserts.assertCount("number of child elements", 0,                   root, "/root/*");
+        DomAsserts.assertEquals("encoded data",            "123456789ABCDEF0",  root, "/root");
+
+        assertType("type attribute", root, "xsd:hexBinary");
+    }
 }
