@@ -1,4 +1,4 @@
-// Copyright 2008-2012 severally by the contributors
+// Copyright 2008-2014 severally by the contributors
 //
 // Licensed under the Apache License, Version 2.0 (the "License");
 // you may not use this file except in compliance with the License.
@@ -32,6 +32,7 @@ import javax.xml.XMLConstants;
 
 import org.w3c.dom.Element;
 
+import net.sf.kdgcommons.test.ArrayAsserts;
 import net.sf.kdgcommons.test.StringAsserts;
 import net.sf.practicalxml.XmlUtil;
 import net.sf.practicalxml.converter.ConversionException;
@@ -1154,4 +1155,46 @@ extends AbstractBeanConverterTestCase
 
         assertEquals("java.util.Date", theDate, bean.getDate());
     }
+
+
+    public void testDefaultByteArrayFormat() throws Exception
+    {
+        byte[] exp = new byte[] { 1, 2, (byte)200 };
+
+        Element data = createTestData(
+                element("value", text("1")),
+                element("value", text("2")),
+                element("value", text("-56")));
+
+        Xml2BeanConverter driver = new Xml2BeanConverter();
+        byte[] dst = driver.convert(data, byte[].class);
+
+        ArrayAsserts.assertEquals(exp, dst);
+    }
+
+
+    public void testByteArrayAsBase64() throws Exception
+    {
+        byte[] exp = new byte[] { 0x12, 0x34, 0x56, 0x78, (byte)0x9A, (byte)0xBC, (byte)0xDE, (byte)0xF0 };
+
+        Element data = createTestData(text("EjRWeJq83vA="));
+
+        Xml2BeanConverter driver = new Xml2BeanConverter(Xml2BeanOptions.BYTE_ARRAYS_AS_BASE64);
+        byte[] dst = driver.convert(data, byte[].class);
+
+        ArrayAsserts.assertEquals(exp, dst);
+    }
+
+
+    public void testByteArrayAsHex() throws Exception
+    {
+        byte[] exp = new byte[] { 0x12, 0x34, 0x56, 0x78, (byte)0x9A, (byte)0xBC, (byte)0xDE, (byte)0xF0 };
+
+        Element data = createTestData(text("123456789ABCDef0"));
+
+        Xml2BeanConverter driver = new Xml2BeanConverter(Xml2BeanOptions.BYTE_ARRAYS_AS_HEX);
+        byte[] dst = driver.convert(data, byte[].class);
+
+        ArrayAsserts.assertEquals(exp, dst);
+    }
 }
